@@ -129,6 +129,8 @@ phi<-(sum((y-Mu)^2/Mu))/(N-sum(diag(FinalHat)))
 Sigma<-Sigma*phi
 }
 
+P1.old.temp<-P1
+
 if(s==1)
 {
   P1<-c(rep(0,lin),rep((Q1^(-1)),n*s))
@@ -172,6 +174,9 @@ print(paste("Final Re-estimation Iteration ", l,sep=""))
 half.index<-0
 solve.test<-FALSE
 
+P1.old<-P1
+P1.old2<-P1.old.temp
+
 Delta_r<-InvFisher%*%score_vec
 ######### big while loop for testing if the update leads to Fisher matrix which can be inverted
 while(!solve.test)
@@ -180,6 +185,11 @@ while(!solve.test)
 solve.test2<-FALSE  
 while(!solve.test2)
 {  
+
+if(half.index>500)
+{
+half.index<-Inf;P1.old<-P1.old2
+}
 Delta[l,]<-Delta[l-1,]+nue*(0.5^half.index)*Delta_r
 
 Eta<-Z_alles%*%Delta[l,]
@@ -189,7 +199,7 @@ D<-as.vector(family$mu.eta(Eta))
 
 if (method=="EM" || overdispersion)
 {  
-  F_gross<-t(Z_alles)%*%(Z_alles*D*1/Sigma*D)+P1
+  F_gross<-t(Z_alles)%*%(Z_alles*D*1/Sigma*D)+P1.old
   InvFisher<-try(chol2inv(chol(F_gross)),silent=TRUE)
   if(class(InvFisher)=="try-error")
     InvFisher<-try(solve(F_gross),silent=TRUE)  
@@ -257,6 +267,8 @@ phi<-(sum((y-Mu)^2/Mu))/(N-sum(diag(FinalHat)))
 Sigma<-Sigma*phi
 }
 
+P1.old.temp<-P1.old
+
 if(s==1)
 {
   P1<-c(rep(0,lin),rep((Q1^(-1)),n*s))
